/**
 * The back in stock settings object holds information related to the state of collecting back in stock
 * notification requests ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/back-in-stock-notifications/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/other-services/back-in-stock/back-in-stock-notifications/introduction)).
 */
interface BackInStockSettings {
    /**
     * Information about collecting customer requests to receive
     * back in stock notifications.
     */
    collectionStates?: BackInStockCollectionState[];
}
interface BackInStockCollectionState {
    /**
     * ID of the app to receive notification requests for.
     *
     * Back in stock notifications only work for [Wix Stores](https://support.wix.com/en/article/wix-stores-about-wix-stores).
     * The `appId` for Wix Stores is `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`.
     * @format GUID
     */
    appId?: string;
    /** Whether to collect requests for items from this app. */
    collectingRequests?: boolean;
}
interface StartCollectingRequestsRequest {
    /**
     * ID of the app to start accepting notification requests for.
     *
     * Back in stock notifications only work for [Wix Stores](https://support.wix.com/en/article/wix-stores-about-wix-stores).
     * The `appId` for Wix Stores is `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`.
     * @format GUID
     */
    appId: string;
}
interface StartCollectingRequestsResponse {
    /** Back in stock settings info. */
    settings?: BackInStockSettings;
}
interface StopCollectingRequestsRequest {
    /**
     * ID of the app to stop accepting notification requests for.
     *
     * Back in stock notifications only work for [Wix Stores](https://support.wix.com/en/article/wix-stores-about-wix-stores).
     * The `appId` for Wix Stores is `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`.
     * @format GUID
     */
    appId: string;
}
interface StopCollectingRequestsResponse {
    /** Back in stock settings info. */
    settings?: BackInStockSettings;
}
interface GetSettingsRequest {
}
interface GetSettingsResponse {
    /** Retrieved back in stock request settings. */
    settings?: BackInStockSettings;
}

export type { BackInStockSettings as B, GetSettingsResponse as G, StartCollectingRequestsResponse as S, StopCollectingRequestsResponse as a, BackInStockCollectionState as b, StartCollectingRequestsRequest as c, StopCollectingRequestsRequest as d, GetSettingsRequest as e };
